pygeodesy.props.property_ROnce

Package pygeodesy :: Module props :: Class property_ROnce |
[frames] | no frames]

# Class property_ROnce

    object --+
             |
      property --+
                 |
     _PropertyBase --+
                     |
       _property_RO___ --+
                         |
                        property_ROnce

Instance Methods
Inherited from `_property_RO___`: `__init__` Inherited from `_PropertyBase`: `deleter`, `getter`, `setter` Inherited from `property`: `__delete__`, `__get__`, `__getattribute__`, `__new__`, `__set__` Inherited from `object`: `__delattr__`, `__format__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `property`: `fdel`, `fget`, `fset` Inherited from `object`: `__class__`